@@ -1,5 +1,5 @@
 package HackaMol::Roles::AtomGroupRole;
-$HackaMol::Roles::AtomGroupRole::VERSION = '0.022';
+$HackaMol::Roles::AtomGroupRole::VERSION = '0.023';
 #ABSTRACT: Role for a group of atoms
 use Moose::Role;
 use Carp;
@@ -29,7 +29,9 @@ has 'atoms' => (
         delete_atoms  => 'delete',
         all_atoms     => 'elements',
         count_atoms   => 'count',
+        natoms        => 'count',
         clear_atoms   => 'clear',
+        has_atoms     => 'count',
     },
     lazy => 1,
 );
@@ -370,7 +372,7 @@ HackaMol::Roles::AtomGroupRole - Role for a group of atoms
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
